==> jc-1.4.0.tar.gz: polyglot/ast/Precedence.h <==
// public class polyglot.ast.Precedence

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6f4f5f315efa9fd7 polyglot_ast_Precedence
// @dep_class 82f09079602e8c27 polyglot_util_Enum

// header file dependencies
// @dep_header polyglot_util_Enum

#include "polyglot/util/Enum.h"

#ifndef _JC_polyglot_ast_Precedence_H_
#define _JC_polyglot_ast_Precedence_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Precedence$object;

// Typedefs
typedef struct _jc_polyglot_ast_Precedence$sub_refs	_jc_polyglot_ast_Precedence$sub_refs;
typedef struct _jc_polyglot_ast_Precedence$sub_nonrefs	_jc_polyglot_ast_Precedence$sub_nonrefs;
typedef struct _jc_polyglot_ast_Precedence$refs	_jc_polyglot_ast_Precedence$refs;
typedef struct _jc_polyglot_ast_Precedence$nonrefs	_jc_polyglot_ast_Precedence$nonrefs;
typedef struct _jc_polyglot_ast_Precedence$object	_jc_polyglot_ast_Precedence$object;

typedef struct _jc_polyglot_ast_Precedence$fields_struct	_jc_polyglot_ast_Precedence$fields_struct;
typedef const struct _jc_polyglot_ast_Precedence$vmethods	_jc_polyglot_ast_Precedence$vmethods;
typedef const struct _jc_polyglot_ast_Precedence$vtable	_jc_polyglot_ast_Precedence$vtable;
typedef const struct _jc_polyglot_ast_Precedence$vtype	_jc_polyglot_ast_Precedence$vtype;

// Class fields structure
struct _jc_polyglot_ast_Precedence$fields_struct {
	struct _jc_polyglot_ast_Precedence$object	*ADD;
	struct _jc_polyglot_ast_Precedence$object	*ASSIGN;
	struct _jc_polyglot_ast_Precedence$object	*BIT__5fAND;
	struct _jc_polyglot_ast_Precedence$object	*BIT__5fOR;
	struct _jc_polyglot_ast_Precedence$object	*BIT__5fXOR;
	struct _jc_polyglot_ast_Precedence$object	*CAST;
	struct _jc_polyglot_ast_Precedence$object	*CONDITIONAL;
	struct _jc_polyglot_ast_Precedence$object	*COND__5fAND;
	struct _jc_polyglot_ast_Precedence$object	*COND__5fOR;
	struct _jc_polyglot_ast_Precedence$object	*EQUAL;
	struct _jc_polyglot_ast_Precedence$object	*INSTANCEOF;
	struct _jc_polyglot_ast_Precedence$object	*LITERAL;
	struct _jc_polyglot_ast_Precedence$object	*MUL;
	struct _jc_polyglot_ast_Precedence$object	*RELATIONAL;
	struct _jc_polyglot_ast_Precedence$object	*SHIFT;
	struct _jc_polyglot_ast_Precedence$object	*STRING__5fADD;
	struct _jc_polyglot_ast_Precedence$object	*UNARY;
	struct _jc_polyglot_ast_Precedence$object	*UNKNOWN;
};
extern _jc_polyglot_ast_Precedence$fields_struct _jc_polyglot_ast_Precedence$class_fields;

// Constructors
extern void _jc_polyglot_ast_Precedence$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_polyglot_ast_Precedence$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern jboolean _jc_polyglot_ast_Precedence$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_ast_Precedence$object *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_polyglot_ast_Precedence$method$equals$db0a577b8d4ec3f0(_jc_env *, struct _jc_polyglot_ast_Precedence$object *, struct _jc_polyglot_ast_Precedence$object *);
extern jboolean _jc_polyglot_ast_Precedence$method$isTighter$52ed86ce37de1b40(_jc_env *, struct _jc_polyglot_ast_Precedence$object *, struct _jc_polyglot_ast_Precedence$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ast_Precedence$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_ast_Precedence$method_info$equals$db0a577b8d4ec3f0;
extern _jc_method _jc_polyglot_ast_Precedence$method_info$isTighter$52ed86ce37de1b40;

// Static methods
extern void _jc_polyglot_ast_Precedence$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_polyglot_ast_Precedence$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_ast_Precedence$object *, struct _jc_java_lang_Object$object *);
	jboolean	(*equals$db0a577b8d4ec3f0)(_jc_env *, struct _jc_polyglot_ast_Precedence$object *, struct _jc_polyglot_ast_Precedence$object *);
	jboolean	(*isTighter$52ed86ce37de1b40)(_jc_env *, struct _jc_polyglot_ast_Precedence$object *, struct _jc_polyglot_ast_Precedence$object *);
};

// Vtable
struct _jc_polyglot_ast_Precedence$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Enum$vmethods	polyglot_util_Enum;
	_jc_polyglot_ast_Precedence$vmethods	polyglot_ast_Precedence;
};

// Vtype
struct _jc_polyglot_ast_Precedence$vtype {
	_jc_type			type;
	_jc_polyglot_ast_Precedence$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ast_Precedence$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ast_Precedence$refs {
    _jc_polyglot_ast_Precedence$sub_refs	polyglot_ast_Precedence;
    _jc_polyglot_util_Enum$sub_refs	polyglot_util_Enum;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ast_Precedence$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_polyglot_ast_Precedence$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Enum$sub_nonrefs	polyglot_util_Enum;
    _jc_polyglot_ast_Precedence$sub_nonrefs	polyglot_ast_Precedence;
};

// Object instance structure
struct _jc_polyglot_ast_Precedence$object {
	_jc_polyglot_ast_Precedence$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ast_Precedence$vtype	*vtype;
	_jc_polyglot_ast_Precedence$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ast_Precedence$vtype _jc_polyglot_ast_Precedence$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ast_Precedence, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ast_Precedence$class_object;

#endif	/* _JC_polyglot_ast_Precedence_H_ */

==> jc-1.4.6.tar.gz: polyglot/ast/Precedence.h <==
// public class polyglot.ast.Precedence

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6f4f5f315efa9fd7 polyglot_ast_Precedence
// @dep_class 82f09079602e8c27 polyglot_util_Enum

// header file dependencies
// @dep_header polyglot_util_Enum

#include "polyglot/util/Enum.h"

#ifndef _JC_polyglot_ast_Precedence_H_
#define _JC_polyglot_ast_Precedence_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Precedence$object;

// Typedefs
typedef struct _jc_polyglot_ast_Precedence$sub_refs	_jc_polyglot_ast_Precedence$sub_refs;
typedef struct _jc_polyglot_ast_Precedence$sub_nonrefs	_jc_polyglot_ast_Precedence$sub_nonrefs;
typedef struct _jc_polyglot_ast_Precedence$refs	_jc_polyglot_ast_Precedence$refs;
typedef struct _jc_polyglot_ast_Precedence$nonrefs	_jc_polyglot_ast_Precedence$nonrefs;
typedef struct _jc_polyglot_ast_Precedence$object	_jc_polyglot_ast_Precedence$object;

typedef struct _jc_polyglot_ast_Precedence$fields_struct	_jc_polyglot_ast_Precedence$fields_struct;
typedef const struct _jc_polyglot_ast_Precedence$vmethods	_jc_polyglot_ast_Precedence$vmethods;
typedef const struct _jc_polyglot_ast_Precedence$vtable	_jc_polyglot_ast_Precedence$vtable;
typedef const struct _jc_polyglot_ast_Precedence$vtype	_jc_polyglot_ast_Precedence$vtype;

// Class fields structure
struct _jc_polyglot_ast_Precedence$fields_struct {
	struct _jc_polyglot_ast_Precedence$object	*ADD;
	struct _jc_polyglot_ast_Precedence$object	*ASSIGN;
	struct _jc_polyglot_ast_Precedence$object	*BIT__5fAND;
	struct _jc_polyglot_ast_Precedence$object	*BIT__5fOR;
	struct _jc_polyglot_ast_Precedence$object	*BIT__5fXOR;
	struct _jc_polyglot_ast_Precedence$object	*CAST;
	struct _jc_polyglot_ast_Precedence$object	*CONDITIONAL;
	struct _jc_polyglot_ast_Precedence$object	*COND__5fAND;
	struct _jc_polyglot_ast_Precedence$object	*COND__5fOR;
	struct _jc_polyglot_ast_Precedence$object	*EQUAL;
	struct _jc_polyglot_ast_Precedence$object	*INSTANCEOF;
	struct _jc_polyglot_ast_Precedence$object	*LITERAL;
	struct _jc_polyglot_ast_Precedence$object	*MUL;
	struct _jc_polyglot_ast_Precedence$object	*RELATIONAL;
	struct _jc_polyglot_ast_Precedence$object	*SHIFT;
	struct _jc_polyglot_ast_Precedence$object	*STRING__5fADD;
	struct _jc_polyglot_ast_Precedence$object	*UNARY;
	struct _jc_polyglot_ast_Precedence$object	*UNKNOWN;
};
extern _jc_polyglot_ast_Precedence$fields_struct _jc_polyglot_ast_Precedence$class_fields;

// Constructors
extern void _jc_polyglot_ast_Precedence$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_polyglot_ast_Precedence$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_ast_Precedence$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_ast_Precedence$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_ast_Precedence$method$equals$db0a577b8d4ec3f0(_jc_env *, struct _jc_polyglot_ast_Precedence$object *, struct _jc_polyglot_ast_Precedence$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_ast_Precedence$method$isTighter$52ed86ce37de1b40(_jc_env *, struct _jc_polyglot_ast_Precedence$object *, struct _jc_polyglot_ast_Precedence$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ast_Precedence$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_ast_Precedence$method_info$equals$db0a577b8d4ec3f0;
extern _jc_method _jc_polyglot_ast_Precedence$method_info$isTighter$52ed86ce37de1b40;

// Static methods
extern void _jc_polyglot_ast_Precedence$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_ast_Precedence$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_ast_Precedence$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$db0a577b8d4ec3f0)(_jc_env *, struct _jc_polyglot_ast_Precedence$object *, struct _jc_polyglot_ast_Precedence$object *) _JC_JCNI_ATTR;
	jboolean	(*isTighter$52ed86ce37de1b40)(_jc_env *, struct _jc_polyglot_ast_Precedence$object *, struct _jc_polyglot_ast_Precedence$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ast_Precedence$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Enum$vmethods	polyglot_util_Enum;
	_jc_polyglot_ast_Precedence$vmethods	polyglot_ast_Precedence;
};

// Vtype
struct _jc_polyglot_ast_Precedence$vtype {
	_jc_type			type;
	_jc_polyglot_ast_Precedence$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ast_Precedence$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ast_Precedence$refs {
    _jc_polyglot_ast_Precedence$sub_refs	polyglot_ast_Precedence;
    _jc_polyglot_util_Enum$sub_refs	polyglot_util_Enum;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ast_Precedence$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_polyglot_ast_Precedence$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Enum$sub_nonrefs	polyglot_util_Enum;
    _jc_polyglot_ast_Precedence$sub_nonrefs	polyglot_ast_Precedence;
};

// Object instance structure
struct _jc_polyglot_ast_Precedence$object {
	_jc_polyglot_ast_Precedence$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ast_Precedence$vtype	*vtype;
	_jc_polyglot_ast_Precedence$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ast_Precedence$vtype _jc_polyglot_ast_Precedence$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ast_Precedence, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ast_Precedence$class_object;

#endif	/* _JC_polyglot_ast_Precedence_H_ */
